==> uptime_widget-8.x-1.0.tar.gz: uptime_widget/src/Form/UptimeAdminSettings.php <==
<?php

namespace Drupal\uptime_widget\Form;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Url;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;

/**
 * {@inheritdoc}
 */
class UptimeAdminSettings extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'uptime_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['uptime_widget.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('uptime_widget.settings');
    $last_refresh = $config->get('next_execution') - $config->get('interval');
    // Essential to have some credentials.
    $api_key = trim($config->get('api_key'));
    $monitor_id = trim($config->get('monitor_id'));
    // Where to find the all-time uptime ratio.
    $url = "http://api.uptimerobot.com/getMonitors?apiKey=" . $api_key . "&monitors=" . $monitor_id . "&format=xml";

    $form['api_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Uptime'),
    ];

    $form['api_settings']['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $config->get('enabled'),
      '#description' => $this->t('Disabling pauses the monitor until re-enabling and removes the ratio display. Disable uptime when your site might go down temporarily,for example during development, or if you want to use only the copyright notice.'),
    ];

    $form['api_settings']['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#default_value' => $api_key,
      '#description' => $this->t('To get an API key go to') . ' ' . \Drupal::l($this->t('https://uptimerobot.com'), Url::fromUri('https://uptimerobot.com/'), [
        'attributes' => ['target' => '_blank'],
      ]) . ' ' . $this->t('▶ Sign-up (free) ▶ Account Activation ▶ Login ▶ Add New Monitor ▶ Monitor Type: HTTP(s) ▶ Create Monitor ▶ My Settings  ▶ Create the main API key  ▶ Copy & paste it here.'),
      '#size' => 40,
      '#maxlength' => 40,
      '#states' => [
        'required' => [
          [':input[name="enabled"]' => ['checked' => TRUE]],
          'or',
          [':input[name="api_key"]' => ['empty' => FALSE]],
          'or',
          [':input[name="monitor_id"]' => ['empty' => FALSE]],
        ],
      ],
    ];

    $form['api_settings']['monitor_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Monitor ID'),
      '#default_value' => $monitor_id,
      '#description' => $this->t('To find your Monitor ID go to') . ' ' . \Drupal::l($this->t('api.uptimerobot.com/getMonitors?apiKey=FILL-IN-YOUR-API-KEY-HERE'), Url::fromUri('http://api.uptimerobot.com/getMonitors?apiKey=FILL-IN-YOUR-API-KEY-HERE'), [
        'attributes' => ['target' => '_blank'],
      ]) . $this->t(', change the last part of the url, reload and copy your monitor ID to here.'),
      '#size' => 10,
      '#maxlength' => 10,
      '#states' => [
        'required' => [
          [':input[name="enabled"]' => ['checked' => TRUE]],
          'or',
          [':input[name="api_key"]' => ['empty' => FALSE]],
          'or',
          [':input[name="monitor_id"]' => ['empty' => FALSE]],
        ],
      ],
    ];

    $form['api_settings']['ratio_decimal_separator'] = [
      '#type' => 'select',
      '#title' => $this->t('Decimal separator'),
      '#options' => [
        '.' => $this->t('Decimal point'),
        ',' => $this->t('Decimal comma'),
      ],
      '#default_value' => $config->get('ratio_decimal_separator'),
      '#description' => $this->t('The decimal separator is a symbol used to mark the border between the integral and the fractional parts of a decimal numeral.'),
      '#required' => TRUE,
    ];

    $form['api_settings']['ratio_scale'] = [
      '#type' => 'number',
      '#title' => $this->t('Scale'),
      '#min' => 0,
      '#max' => 3,
      '#default_value' => $config->get('ratio_scale'),
      '#description' => $this->t('The number of digits to the right of the decimal. Allowed range 0-3.'),
      '#required' => TRUE,
    ];

    // Grabbing the uptime ratio once a day is good enough, but leave it up to
    // the site owner to decide. Second option is the actual set cron interval.
    $form['api_settings']['interval'] = [
      '#type' => 'radios',
      '#title' => $this->t('Refresh interval'),
      '#options' => [
        86400 => $this->t('24 hours (recommended)'),
        0 => $this->t('Every cron run'),
      ],
      '#default_value' => $config->get('interval'),
      '#description' => $this->t('Saving this form refreshes the uptime ratio instantly, independent from this setting. Last refresh was') . ' ' . $this->t('@interval ago', ['@interval' => \Drupal::service('date.formatter')->formatInterval((REQUEST_TIME - $last_refresh))]) . '.',
      '#required' => TRUE,
    ];

    // Offering the possibility to check the source of the data.
    $form['api_settings']['raw check'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Data check'),
      '#description' => $this->t('Once you saved your credentials, you can check the raw data at') . ':<br />' . \Drupal::l($url, Url::fromUri($url), [
        'attributes' => ['target' => '_blank'],
      ])
      . '<br />' . $this->t('The current Uptime ratio is @ratio %.', ['@ratio' => $config->get('ratio')]),
    ];

    $form['notice'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Copyright notice'),
    ];

    $form['notice']['notice_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $config->get('notice_enabled'),
    ];

    // For the examples we use real data.
    // Current domain name without the leading protocol.
    $host = \Drupal::config('uptime_widget.settings')->get('url_name');
    if (!isset($host) || empty($host)) {
      \Drupal::configFactory()->getEditable('uptime_widget.settings')->set('url_name', parse_url($GLOBALS['base_url'], PHP_URL_HOST))->save();
    }
    if ($host != parse_url($GLOBALS['base_url'], PHP_URL_HOST)) {
      $host = parse_url($GLOBALS['base_url'], PHP_URL_HOST);
    }
    $year = $config->get('year');
    $notice = $config->get('prepend') . ' ©' . (($year != date('Y') && !empty($year)) ? $year . '-' . date('Y') : date('Y'));
    $form['notice']['url_name'] = [
      // Create different types of notices to choose from.
      '#type' => 'radios',
      '#title' => $this->t('Choose a notice'),
      '#options' => [
        $host => '<strong>' . $notice . ' ' . $host . '</strong> ' . $this->t('(Base url. Default.)'),
        $this->config('system.site')->get('name') => '<strong>' . $notice . ' ' . $this->config('system.site')->get('name') . '</strong> ' . $this->t("(Site name. Preferable if the site name is a person's full name or a company name.)"),
        ' ' => '<strong>' . $notice . '</strong> ' . $this->t('(Leaving out the designation of owner is not recommended.)'),
      ],
      '#default_value' => $host,
      '#description' => $this->t("'Year of first publication' is not used until entered below, for example © 2009-") . date('Y') . '. ' . t('Save this form to refresh above examples.'),
    ];

    $form['notice']['year'] = [
      '#type' => 'textfield',
      '#title' => $this->t('What year was the domain first online?'),
      '#default_value' => $year,
      '#description' => $this->t("Leave empty to display only the current year (default). Also if the 'starting year' equals the 'current year' only one will be displayed until next year."
        . '<br />' . $this->t("To play safe legally, it's best to enter a 'Year of first publication', although copyright is in force even without any notice.")),
      '#size' => 4,
      '#maxlength' => 4,
    ];

    $form['notice']['prepend'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Prepend text'),
      '#default_value' => trim($config->get('prepend')),
      '#description' => $this->t("For example 'All images' on a photographer's website."),
    ];

    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->getValue(['api_key']) && $form_state->getValue(['monitor_id'])) {
      $monitor_id = $form_state->getValue(['monitor_id']);
      if (!is_numeric($monitor_id)) {
        $form_state->setErrorByName('monitor_id', $this->t('Monitor ID should be a number.'));
      }

      // Pause or activate update monitoring depending on the 'enabled' checkbox.
      $url = 'https://api.uptimerobot.com/v2/editMonitor';
      $response = \Drupal::httpClient()->post($url, [
        'headers' => [
          'Content-Type' => "application/x-www-form-urlencoded",
          'Cache-Control' => "no-cache",
        ],
        'form_params' => [
          'api_key' => $form_state->getValue(['api_key']),
          'id' => $form_state->getValue('monitor_id'),
          'format' => 'json',
          'status' => $form_state->getValue('enabled')
        ],
      ]);
      $data = Json::decode((string) $response->getBody());
      if (isset($data['error']['type'])) {
        if (isset($data['error']['parameter_name']) && $data['error']['type'] == 'invalid_parameter' && $data['error']['parameter_name'] == 'api_key') {
          $form_state->setErrorByName('api_key', $this->t('Invalid API Key.'));
        }
        if ($data['error']['type'] == 'not_found') {
          $form_state->setErrorByName('monitor_id', $this->t('Invalid Monitor ID.'));
        }
      }
    }

    // Before 1991 there was no world wide web and the future can't be a
    // 'year of first publication' but it can be left empty.
    $year = $form_state->getValue('year');
    if ((!is_numeric($year) || $year < 1991 || $year > date('Y')) && !empty($year)) {
      $form_state->setErrorByName('year', $this->t('Invalid year.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Execution time has to be reset to force an instant cron run.
    $this->configFactory()->getEditable('uptime_widget.settings')
      ->set('next_execution', 0)
      ->set('enabled', $form_state->getValue('enabled'))
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('monitor_id', $form_state->getValue('monitor_id'))
      ->set('ratio_scale', $form_state->getValue('ratio_scale'))
      ->set('ratio_decimal_separator', $form_state->getValue('ratio_decimal_separator'))
      ->set('interval', $form_state->getValue('interval'))
      ->set('notice_enabled', $form_state->getValue('notice_enabled'))
      ->set('year', $form_state->getValue('year'))
      ->set('prepend', $form_state->getValue('prepend'))
      ->set('url_name', $form_state->getValue('url_name'))
      ->save();
    // To find a cron call here looks odd, but it's the only way to have any
    // changed variables in the form being processed in the hook_cron(). After
    // submitting the form you come back on the same form and that's when all
    // new variables are available.
    \Drupal::service('cron')->run();
    drupal_flush_all_caches();

    if ($form_state->getValue('enabled')) {
      drupal_set_message($this->t('The monitor is running.'));
    }
    else {
      drupal_set_message($this->t('The monitor is paused.'));
    }
    drupal_set_message($this->t('The configuration options have been saved.'));
  }

}

==> uptime_widget-8.x-1.1.tar.gz: uptime_widget/src/Form/UptimeAdminSettings.php <==
<?php

namespace Drupal\uptime_widget\Form;

use Drupal\Component\Serialization\Json;
use Drupal\Core\Url;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;

/**
 * {@inheritdoc}
 */
class UptimeAdminSettings extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'uptime_admin_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['uptime_widget.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('uptime_widget.settings');
    $last_refresh = $config->get('next_execution') - $config->get('refresh_interval');
    // Essential to have some credentials.
    $api_key = trim($config->get('api_key'));
    $monitor_id = trim($config->get('monitor_id'));
    // Where to find the all-time uptime ratio.
    $url = "http://api.uptimerobot.com/getMonitors?apiKey=" . $api_key . "&monitors=" . $monitor_id . "&format=xml";

    $form['api_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Uptime'),
    ];

    $form['api_settings']['enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $config->get('enabled'),
      '#description' => $this->t('Disabling pauses the monitor until re-enabling and removes the ratio display. Disable uptime when your site might go down temporarily,for example during development, or if you want to use only the copyright notice.'),
    ];

    $form['api_settings']['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API key'),
      '#default_value' => $api_key,
      '#description' => $this->t('To get an API key go to') . ' ' . \Drupal::l($this->t('https://uptimerobot.com'), Url::fromUri('https://uptimerobot.com/'), [
        'attributes' => ['target' => '_blank'],
      ]) . ' ' . $this->t('▶ Sign-up (free) ▶ Account Activation ▶ Login ▶ Add New Monitor ▶ Monitor Type: HTTP(s) ▶ Create Monitor ▶ My Settings  ▶ Create the main API key  ▶ Copy & paste it here.'),
      '#size' => 40,
      '#maxlength' => 40,
      '#states' => [
        'required' => [
          [':input[name="enabled"]' => ['checked' => TRUE]],
          'or',
          [':input[name="api_key"]' => ['empty' => FALSE]],
          'or',
          [':input[name="monitor_id"]' => ['empty' => FALSE]],
        ],
      ],
    ];

    $form['api_settings']['monitor_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Monitor ID'),
      '#default_value' => $monitor_id,
      '#description' => $this->t('To find your Monitor ID go to') . ' ' . \Drupal::l($this->t('api.uptimerobot.com/getMonitors?apiKey=FILL-IN-YOUR-API-KEY-HERE'), Url::fromUri('http://api.uptimerobot.com/getMonitors?apiKey=FILL-IN-YOUR-API-KEY-HERE'), [
        'attributes' => ['target' => '_blank'],
      ]) . $this->t(', change the last part of the url, reload and copy your monitor ID to here.'),
      '#size' => 10,
      '#maxlength' => 10,
      '#states' => [
        'required' => [
          [':input[name="enabled"]' => ['checked' => TRUE]],
          'or',
          [':input[name="api_key"]' => ['empty' => FALSE]],
          'or',
          [':input[name="monitor_id"]' => ['empty' => FALSE]],
        ],
      ],
    ];

    $form['api_settings']['ratio_decimal_separator'] = [
      '#type' => 'select',
      '#title' => $this->t('Decimal separator'),
      '#options' => [
        '.' => $this->t('Decimal point'),
        ',' => $this->t('Decimal comma'),
      ],
      '#default_value' => $config->get('ratio_decimal_separator'),
      '#description' => $this->t('The decimal separator is a symbol used to mark the border between the integral and the fractional parts of a decimal numeral.'),
      '#required' => TRUE,
    ];

    $form['api_settings']['ratio_scale'] = [
      '#type' => 'number',
      '#title' => $this->t('Scale'),
      '#min' => 0,
      '#max' => 3,
      '#default_value' => $config->get('ratio_scale'),
      '#description' => $this->t('The number of digits to the right of the decimal. Allowed range 0-3.'),
      '#required' => TRUE,
    ];

    $form['api_settings']['nocss'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('No CSS'),
      '#default_value' => $config->get('nocss'),
      '#description' => $this->t("Do not apply the module's supplied CSS."),
    ];

    $form['api_settings']['monitoring_interval'] = [
      '#type' => 'range',
      '#title' => $this->t('Monitoring interval'),
      '#min' => 5,
      '#max' => 142,
      '#step' => 1,
      '#default_value' => $config->get('monitoring_interval'),
      '#description' => $this->t('The interval for the monitoring check by UptimeRobot (5 minutes by default). Allowed range 5 minutes - 24 hours.'),
      '#required' => TRUE,
      '#theme' => 'uptime_range',
    ];

    // Grabbing the uptime ratio once a day is good enough, but leave it up to
    // the site owner to decide. Second option is the actual set cron interval.
    $form['api_settings']['refresh_interval'] = [
      '#type' => 'radios',
      '#title' => $this->t('Refresh interval'),
      '#options' => [
        86400 => $this->t('24 hours (recommended)'),
        0 => $this->t('Every cron run'),
      ],
      '#default_value' => $config->get('refresh_interval'),
      '#description' => $this->t('Saving this form refreshes the uptime ratio instantly, independent from this setting. Last refresh was @interval ago.', ['@interval' => \Drupal::service('date.formatter')->formatInterval((REQUEST_TIME - $last_refresh))]),
      '#required' => TRUE,
    ];

    // Offering the possibility to check the source of the data.
    $api_settings_raw_check_description = $this->t('Once you saved your credentials, you can check the raw data at');
    $api_settings_raw_check_description .= ':<br />';
    $api_settings_raw_check_description .= \Drupal::l($url, Url::fromUri($url), [
      'attributes' => ['target' => '_blank'],
    ]);
    $api_settings_raw_check_description .= '<br />' . $this->t('The current Uptime ratio is @ratio %.', ['@ratio' => $config->get('ratio')]);
    $form['api_settings']['raw check'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Data check'),
      '#description' => $api_settings_raw_check_description,
    ];

    $form['notice'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Copyright notice'),
    ];

    $form['notice']['notice_enabled'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enabled'),
      '#default_value' => $config->get('notice_enabled'),
    ];

    // For the examples we use real data.
    // Current domain name without the leading protocol.
    $host = \Drupal::config('uptime_widget.settings')->get('url_name');
    if (!isset($host) || empty($host)) {
      \Drupal::configFactory()->getEditable('uptime_widget.settings')->set('url_name', parse_url($GLOBALS['base_url'], PHP_URL_HOST))->save();
    }
    if ($host != parse_url($GLOBALS['base_url'], PHP_URL_HOST)) {
      $host = parse_url($GLOBALS['base_url'], PHP_URL_HOST);
    }
    $year = $config->get('year');
    $notice = $config->get('prepend') . ' ©' . (($year != date('Y') && !empty($year)) ? $year . '-' . date('Y') : date('Y'));
    $form['notice']['url_name'] = [
      // Create different types of notices to choose from.
      '#type' => 'radios',
      '#title' => $this->t('Choose a notice'),
      '#options' => [
        $host => '<strong>' . $notice . ' ' . $host . '</strong> ' . $this->t('(Base url. Default.)'),
        $this->config('system.site')->get('name') => '<strong>' . $notice . ' ' . $this->config('system.site')->get('name') . '</strong> ' . $this->t("(Site name. Preferable if the site name is a person's full name or a company name.)"),
        ' ' => '<strong>' . $notice . '</strong> ' . $this->t('(Leaving out the designation of owner is not recommended.)'),
      ],
      '#default_value' => $host,
      '#description' => $this->t("'Year of first publication' is not used until entered below, for example © 2009-") . date('Y') . '. ' . t('Save this form to refresh above examples.'),
    ];

    $notice_year_description = $this->t("Leave empty to display only the current year (default). Also if the 'starting year' equals the 'current year' only one will be displayed until next year.");
    $notice_year_description .= '<br />' . $this->t("To play safe legally, it's best to enter a 'Year of first publication', although copyright is in force even without any notice.");
    $form['notice']['year'] = [
      '#type' => 'textfield',
      '#title' => $this->t('What year was the domain first online?'),
      '#default_value' => $year,
      '#description' => $notice_year_description,
      '#size' => 4,
      '#maxlength' => 4,
    ];

    $form['notice']['prepend'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Prepend text'),
      '#default_value' => trim($config->get('prepend')),
      '#description' => $this->t("For example 'All images' on a photographer's website."),
    ];

    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->getValue(['api_key']) && $form_state->getValue(['monitor_id'])) {
      $monitor_id = $form_state->getValue(['monitor_id']);
      if (!is_numeric($monitor_id)) {
        $form_state->setErrorByName('monitor_id', $this->t('Monitor ID should be a number.'));
      }

      // Calculate monitoring interval in seconds.
      $monitoring_interval = $form_state->getValue('monitoring_interval');
      if ($monitoring_interval > 120) {
        // After 120 minutes we show 3 hours. So current value in days.
        $monitoring_interval = ($monitoring_interval - 118) * 3600;
      }
      else {
        // Current value in minutes.
        $monitoring_interval *= 60;
      }

      // Pause or activate monitoring depending on the 'enabled' checkbox.
      $url = 'https://api.uptimerobot.com/v2/editMonitor';
      $response = \Drupal::httpClient()->post($url, [
        'headers' => [
          'Content-Type' => "application/x-www-form-urlencoded",
          'Cache-Control' => "no-cache",
        ],
        'form_params' => [
          'api_key' => $form_state->getValue(['api_key']),
          'id' => $form_state->getValue('monitor_id'),
          'format' => 'json',
          // Convert time from minutes to seconds.
          'interval' => $monitoring_interval,
          'status' => $form_state->getValue('enabled'),
        ],
      ]);
      $data = Json::decode((string) $response->getBody());
      if (isset($data['error']['type'])) {
        if (isset($data['error']['parameter_name']) && $data['error']['type'] == 'invalid_parameter' && $data['error']['parameter_name'] == 'api_key') {
          $form_state->setErrorByName('api_key', $this->t('Invalid API Key.'));
        }
        if ($data['error']['type'] == 'not_found') {
          $form_state->setErrorByName('monitor_id', $this->t('Invalid Monitor ID.'));
        }
      }
    }

    // Before 1991 there was no world wide web and the future can't be a
    // 'year of first publication' but it can be left empty.
    $year = $form_state->getValue('year');
    if ((!is_numeric($year) || $year < 1991 || $year > date('Y')) && !empty($year)) {
      $form_state->setErrorByName('year', $this->t('Invalid year.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Execution time has to be reset to force an instant cron run.
    $this->configFactory()->getEditable('uptime_widget.settings')
      ->set('next_execution', 0)
      ->set('enabled', $form_state->getValue('enabled'))
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('monitor_id', $form_state->getValue('monitor_id'))
      ->set('ratio_scale', $form_state->getValue('ratio_scale'))
      ->set('ratio_decimal_separator', $form_state->getValue('ratio_decimal_separator'))
      ->set('nocss', $form_state->getValue('nocss'))
      ->set('monitoring_interval', $form_state->getValue('monitoring_interval'))
      ->set('refresh_interval', $form_state->getValue('refresh_interval'))
      ->set('notice_enabled', $form_state->getValue('notice_enabled'))
      ->set('year', $form_state->getValue('year'))
      ->set('prepend', $form_state->getValue('prepend'))
      ->set('url_name', $form_state->getValue('url_name'))
      ->save();
    // To find a cron call here looks odd, but it's the only way to have any
    // changed variables in the form being processed in the hook_cron(). After
    // submitting the form you come back on the same form and that's when all
    // new variables are available.
    \Drupal::service('cron')->run();
    drupal_flush_all_caches();

    if ($form_state->getValue('enabled')) {
      drupal_set_message($this->t('The monitor is running.'));
    }
    else {
      drupal_set_message($this->t('The monitor is paused.'));
    }
    drupal_set_message($this->t('The configuration options have been saved.'));
  }

}
